@@ -1,7 +1,7 @@
 (function($){
-    $(document).ready(function(){
-        $.fn.django_cascading_dropdown_widget = function(){
-            $(this).change(function(){
+    $.fn.django_cascading_dropdown_widget = function(){
+        return this.each(function(){
+            $(this).find(".django-cascading-dropdown-widget-select").change(function(){
                 var value = $(this).val();
                 var name = $(this).attr("data-name");
                 var show_name = name + "-" + value;
@@ -10,15 +10,16 @@
                 var next_select = $(this).nextAll(".django-cascading-dropdown-widget-select[data-name=" + show_name + "]");
                 if(next_select.length > 0){
                     next_select.show();
-                    input.val("");
+                    input.val("").change();
                 }else{
-                    input.val(value);
+                    input.val(value).change();
                 }
             });
-        };
-        $(".django-cascading-dropdown-widget-select").django_cascading_dropdown_widget();
-        $(document.body).arrive(".django-cascading-dropdown-widget-select", function(){
-            $(this).django_cascading_dropdown_widget();
         });
+    };
+    $(document).arrive(".django-cascading-dropdown-widget", {
+        existing: true
+    }, function(){
+        $(this).django_cascading_dropdown_widget();
     });
 })(jQuery);
