@@ -173,7 +173,7 @@ class DjangoCascadingDropdownWidget(Input):
         }
         js = [
             "jquery3/jquery.js",
-            "django-cascading-dropdown-widget/js/arrive.min.js",
+            "arrive/arrive.min.js",
             "django-cascading-dropdown-widget/js/django-cascading-dropdown-widget.js",
         ]
 
